import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/eravellisaimeghana/9a7aa1216624c57000794c17c3638628/raw/45ef9e490c7373d7a5919fa373cf45008374e6d3/maggi.csv';
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'Species';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'setosa':
              return 'green';
            case 'versicolor':
              return 'brown';
            case 'virginica':
              return 'magenta';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 34,
      right: 55,
      bottom: 90,
      left: 95,

    })
    .radius(6);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -80)
          .attr('y', -210)
          .style("font-style","serif")
          .style("stroke","black")
          .text(colorLabel);

   
// for the title
svg.append("text").attr("x", 450).attr("y", 20).text("Iris Scatterplot").style("font-size", "25px").attr("alignment-baseline","middle")

   

svg.append("text").attr("x", 150).attr("y", 70).text("Setosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Versicolor").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Virginica").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","serif")
        	.style("font-weight","bold")
        	.text("Sepal Length");
    
    // legends
    svg.append("circle").attr("cx",120).attr("cy",70).attr("r", 5).style("fill", "green")
		svg.append("circle").attr("cx",120).attr("cy",100).attr("r", 5).style("fill", "brown")
		svg.append("circle").attr("cx",120).attr("cy",130).attr("r", 5).style("fill", "magenta")
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  450 )
        	.style("text-anchor", "middle")
        	.style("font-style","serif")
        	.style("font-weight","bold")
      		.text("Petal Width");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  450 )
        	.style("text-anchor", "middle")
        	.style("font-style","serif")
        	.style("font-weight","bold")
      		.text("Sepal Width");
     // make plotting of petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  450 )
        	.style("text-anchor", "middle")
        	.style("font-style","serif")
        	.style("font-weight","bold")
      		.text("Petal Length");
     //make plotting of sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  450 )
        	.style("text-anchor", "middle")
        	.style("font-style","serif")
        	.style("font-weight","bold")
      		.text("Sepal Length");
    i++;
  }, 2000);// for each 2 seconds changes the visualizations.
};
main();



